Include "disk.dat";

Group
{
    Omega = Region[{DOMAIN, INFY1, INFY2, INFX}];
    GamaDirichlet1 = Region[{DISK}];
    GamaDirichlet2 = Region[{BNDINF}];
    GamaNeumann = Region[{AXISY}];
    InfX = Region[{INFX}];
    InfY = Region[{INFY1, INFY2}];
    OmegaTotal = Region[{Omega,GamaDirichlet1,GamaDirichlet2,GamaNeumann}];
}

Jacobian {
  { Name JVol ;
    Case {
      { Region InfX; Jacobian VolAxiRectShell {x_max-x_width, x_max, 1};}
      { Region InfY; Jacobian VolAxiRectShell {y_max-y_width, y_max, 2};}
      { Region All ; Jacobian VolAxi ; }
    }
  }
}

Integration {
  { Name I1 ;
    Case {
      { Type Gauss ;
        Case {
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  3 ; }
	  { GeoElement Triangle    ; NumberOfPoints  4 ; }
	  { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
	  { GeoElement Prism       ; NumberOfPoints  6 ; }
	}
      }
    }
  }
}

phi = 10;


Constraint
{
    {Name DirichletBC; Type Assign;
	    Case
	    {
		{Region GamaDirichlet1; Value phi;}
		{Region GamaDirichlet2; Value 0;}
	    }
    }
}

FunctionSpace
{
    {
        Name Vh; Type Form0;
        BasisFunction
        {
        {Name wn; NameOfCoef vn; Function BF_Node;
         Support OmegaTotal; Entity NodesOf[All];}
        }
        Constraint{
        {
         NameOfCoef vn; EntityType NodesOf;
         NameOfConstraint DirichletBC;
        }
        }
    }
}

Formulation
{
    {
        Name DiskPotential; Type FemEquation;
        Quantity
        {
            {Name u; Type Local; NameOfSpace Vh;}
        }
        Equation
        {
            Galerkin{ [Dof{Grad u}, {Grad u}]; In Omega; Jacobian JVol; Integration I1;}
        }
    }
}

Resolution
{
    {
        Name DiskPotential;
        System
        {
            {Name Syst; NameOfFormulation DiskPotential;}
        }
        Operation
        {
            Generate[Syst]; Solve[Syst]; SaveSolution[Syst];
        }
    }
}

PostProcessing{
  {Name DiskPotential; NameOfFormulation DiskPotential;
    Quantity{
      {Name u; Value {Local{[{u}]; In Omega; Jacobian JVol;}}}
    }
  }
}

PostOperation{
  {Name Map_u; NameOfPostProcessing DiskPotential;
    Operation{
      Print[u, OnElementsOf Omega, File "u.pos"];
    }
  }
}

